@@ -3,7 +3,8 @@ const project = new awscdk.AwsCdkConstructLibrary({
   author: 'yicr',
   authorAddress: 'yicr@users.noreply.github.com',
   cdkVersion: '2.80.0',
-  typescriptVersion: '5.0.4',
+  typescriptVersion: '4.9.x',
+  jsiiVersion: '~5.0.0',
   defaultReleaseBranch: 'main',
   name: '@gammarer/aws-secure-flow-log-bucket',
   description: 'Specific AWS VPC FlowLog Bucket',
@@ -12,17 +13,18 @@ const project = new awscdk.AwsCdkConstructLibrary({
   repositoryUrl: 'https://github.com/yicr/aws-secure-flow-log-bucket.git',
   npmAccess: javascript.NpmAccess.PUBLIC,
   deps: [
-    '@gammarer/aws-secure-log-bucket',
+    '@gammarer/aws-secure-log-bucket@~0.12',
   ],
   peerDeps: [
     '@gammarer/aws-secure-log-bucket',
+    '@gammarer/aws-secure-bucket',
   ],
-  minNodeVersion: '16.0.0',
-  workflowNodeVersion: '16.19.1',
+  minNodeVersion: '18.0.0',
+  workflowNodeVersion: '18.17.1',
   depsUpgradeOptions: {
     workflowOptions: {
       labels: ['auto-approve', 'auto-merge'],
-      schedule: javascript.UpgradeDependenciesSchedule.expressions(['0 18 * * *']),
+      schedule: javascript.UpgradeDependenciesSchedule.expressions(['0 19 * * 0']), // every sunday (JST/MON:04:00)
     },
   },
   autoApproveOptions: {
@@ -33,5 +35,11 @@ const project = new awscdk.AwsCdkConstructLibrary({
     distName: 'gammarer.aws-secure-flow-log-bucket',
     module: 'gammarer.aws_secure_flow_log_bucket',
   },
+  publishToMaven: {
+    mavenGroupId: 'com.gammarer',
+    javaPackage: 'com.gammarer.cdk.aws.secure_flow_log_bucket',
+    mavenArtifactId: 'aws-secure-flow-log-bucket',
+    mavenEndpoint: 'https://s01.oss.sonatype.org',
+  },
 });
 project.synth();
\ No newline at end of file
